@@ -1,3 +1,9 @@
+if(typeof String.prototype.trim !== 'function') {
+  String.prototype.trim = function() {
+    return this.replace(/^\s+|\s+$/g, ''); 
+  };
+}
+
 var camposObrigatorios = ["#cartao_nome", "#cartao_numero", "#cartao_data_expiracao", "#cartao_cvv"];
 $(function() {
     $("#formas-pagamento-wrapper").on("click", "#finalizarCompra", function(event) {
@@ -149,4 +155,4 @@ var Parcela = {
         }
         this.$campoParcelas.html(options.join());
     }
-};
\ No newline at end of file
+};
